@@ -10,7 +10,7 @@ def env_to_django(mappings):
         try:
             result[django_var] = os.environ[env]
         except:
-            print 'Problem fetching environment variable %s' % env
+            print('Problem fetching environment variable {}'.format(env))
             raise
 
     return result
@@ -23,7 +23,7 @@ def env_to_env(mappings):
         try:
             result[new_env] = os.environ[env]
         except:
-            print 'Problem fetching environment variable %s' % env
+            print(Problem fetching environment variable {}'.format(env))
             raise
 
     os.environ.update(result)
@@ -57,7 +57,7 @@ def memcachier():
         result = env_to_env(mapping)
         caches = {
             'default': {
-                'BACKEND': 'django_pylibmc.memcached.PyLibMCCache',
+                'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
                 'LOCATION': result['MEMCACHE_SERVERS'],
                 'TIMEOUT': 500,
                 'BINARY': True
